Provides types for CNB data formats. Is a re-export of the libcnb-data crate.
libcnb-data

Provides types for data formats specified in the Cloud Native Buildpack specification.
If you wish to create buildpacks using the libcnb.rs framework, use the libcnb crate rather than depending on this crate directly.
Modules
- build
- build_
plan - buildpack
- buildpack_
plan - exec_d
- generic
- launch
- layer
- layer_
content_ metadata - package_
descriptor - sbom
- store
Macros
- buildpack_
id - Construct a
BuildpackIdvalue at compile time. - exec_
d_ program_ output_ key - Construct a
ExecDProgramOutputKeyvalue at compile time. - layer_
name - Construct a
LayerNamevalue at compile time. - process_
type - Construct a
ProcessTypevalue at compile time.