Struct libcnb::Env

source ·
pub struct Env { /* private fields */ }
Generic collection of environment variables.

Examples

use std::process::Command;
use libcnb::Env;

let mut env = Env::new();
env.insert("FOO", "BAR");
env.insert("BAZ", "BLAH");

let output = Command::new("printenv")
    .env_clear()
    .envs(&env)
    .output()
    .unwrap();

assert_eq!(
    "BAZ=BLAH\nFOO=BAR\n",
    String::from_utf8_lossy(&output.stdout)
);

Implementations

Creates a new Env from all the environment variables of the current process.

The returned Env contains a snapshot of the process’s environment variables at the time of this invocation. Modifications to environment variables afterwards will not be reflected in the returned value.

See std::env::vars_os

Creates an empty Env struct.

Inserts a key-value pair into the environment, overriding the value if key was already present.

Returns a cloned value corresponding to the given key.

Returns true if the environment contains a value for the specified key.